add parted-use-ext-range.patch (bnc#715695)

OBS-URL: https://build.opensuse.org/package/show/Base:System/parted?expand=0&rev=47
This commit is contained in:
Petr Uzel 2011-09-05 12:34:13 +00:00 committed by Git OBS Bridge
parent 3f364e53db
commit 58f21d3b6a
3 changed files with 29 additions and 0 deletions

View File

@ -0,0 +1,22 @@
Index: parted-2.4/libparted/arch/linux.c
===================================================================
--- parted-2.4.orig/libparted/arch/linux.c
+++ parted-2.4/libparted/arch/linux.c
@@ -2413,7 +2413,7 @@ _blkpg_remove_partition (PedDisk* disk,
/*
* The number of partitions that a device can have depends on the kernel.
* If we don't find this value in /sys/block/DEV/range, we will use our own
* value.
*/
static unsigned int
@@ -2424,7 +2424,7 @@ _device_get_partition_range(PedDevice* d
FILE* fp;
bool ok;
- r = snprintf(path, sizeof(path), "/sys/block/%s/range",
+ r = snprintf(path, sizeof(path), "/sys/block/%s/ext_range",
last_component(dev->path));
if (r < 0 || r >= sizeof(path))
return MAX_NUM_PARTS;

View File

@ -1,3 +1,8 @@
-------------------------------------------------------------------
Mon Sep 5 12:08:48 UTC 2011 - puzel@suse.com
- add parted-use-ext-range.patch (bnc#715695)
-------------------------------------------------------------------
Thu Aug 25 10:22:09 UTC 2011 - puzel@novell.com

View File

@ -41,6 +41,7 @@ Patch11: do-not-create-dm-nodes.patch
Patch12: more-reliable-informing-the-kernel.patch
Patch13: parted-2.4-ncursesw6.patch
Patch14: parted-gpt-sync-mbr-label.patch
Patch15: parted-use-ext-range.patch
Requires: /sbin/udevadm
BuildRequires: check-devel
BuildRequires: device-mapper-devel >= 1.02.33
@ -105,6 +106,7 @@ to develop applications that require these.
%patch12 -p1
%patch13
%patch14 -p1
@@ -2413,7 +2413,7 @@ _blkpg_remove_partition (PedDisk* disk,
/*
* The number of partitions that a device can have depends on the kernel.
- * If we don't find this value in /sys/block/DEV/range, we will use our own
+ * If we don't find this value in /sys/block/DEV/ext_range, we will use our own
* value.
*/
%patch15 -p1
%build
export CFLAGS="%{optflags} `ncursesw6-config --cflags`"